summaryrefslogtreecommitdiffstats
path: root/src/kvirc/kvs
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:40:04 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:40:04 -0600
commitf91149819be7e7f45e68f22876f3c0062a11d4b9 (patch)
treeea2e0b384a225b9fcedd5ec44e08d1ad2fc2570b /src/kvirc/kvs
parent32a249baaef1b910bffd79734c78cac3671f00f2 (diff)
downloadkvirc-f91149819be7e7f45e68f22876f3c0062a11d4b9.tar.gz
kvirc-f91149819be7e7f45e68f22876f3c0062a11d4b9.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'src/kvirc/kvs')
-rw-r--r--src/kvirc/kvs/kvi_kvs_eventtable.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_object.cpp42
-rw-r--r--src/kvirc/kvs/kvi_kvs_object.h2
-rw-r--r--src/kvirc/kvs/kvi_kvs_object_controller.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_processmanager.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp2
6 files changed, 26 insertions, 26 deletions
diff --git a/src/kvirc/kvs/kvi_kvs_eventtable.cpp b/src/kvirc/kvs/kvi_kvs_eventtable.cpp
index 55c086d..b2fc61b 100644
--- a/src/kvirc/kvs/kvi_kvs_eventtable.cpp
+++ b/src/kvirc/kvs/kvi_kvs_eventtable.cpp
@@ -254,7 +254,7 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
@description:
This event is triggered in the first console of a new frame window.
A frame window is the toplevel window that contains the consoles
- and the other MDI tqchildren windows.
+ and the other MDI children windows.
@seealso:
[event:onframewindowdestroyed]OnFrameWindowDestroyed[/event]
*/
diff --git a/src/kvirc/kvs/kvi_kvs_object.h b/src/kvirc/kvs/kvi_kvs_object.h
index a19bd5f..f59c098 100644
--- a/src/kvirc/kvs/kvi_kvs_object.h
+++ b/src/kvirc/kvs/kvi_kvs_object.h
@@ -164,7 +164,7 @@ protected:
bool function_findChild(KviKvsObjectFunctionCall *c);
bool function_childCount(KviKvsObjectFunctionCall *c);
bool function_emit(KviKvsObjectFunctionCall *c);
- bool function_tqchildren(KviKvsObjectFunctionCall *c);
+ bool function_children(KviKvsObjectFunctionCall *c);
bool function_signalSender(KviKvsObjectFunctionCall *c);
bool function_signalName(KviKvsObjectFunctionCall *c);
bool function_destructor(KviKvsObjectFunctionCall *c);
diff --git a/src/kvirc/kvs/kvi_kvs_object_controller.cpp b/src/kvirc/kvs/kvi_kvs_object_controller.cpp
index b2c1c8b..4739f33 100644
--- a/src/kvirc/kvs/kvi_kvs_object_controller.cpp
+++ b/src/kvirc/kvs/kvi_kvs_object_controller.cpp
@@ -73,7 +73,7 @@ void KviKvsObjectController::init()
m_pObjectClass->registerFunctionHandler("findChild",KVI_PTR2MEMBER(KviKvsObject::function_findChild));
m_pObjectClass->registerFunctionHandler("childCount",KVI_PTR2MEMBER(KviKvsObject::function_childCount));
m_pObjectClass->registerFunctionHandler("emit",KVI_PTR2MEMBER(KviKvsObject::function_emit));
- m_pObjectClass->registerFunctionHandler("tqchildren",KVI_PTR2MEMBER(KviKvsObject::function_tqchildren));
+ m_pObjectClass->registerFunctionHandler("children",KVI_PTR2MEMBER(KviKvsObject::function_children));
m_pObjectClass->registerFunctionHandler("signalSender",KVI_PTR2MEMBER(KviKvsObject::function_signalSender));
m_pObjectClass->registerFunctionHandler("signalName",KVI_PTR2MEMBER(KviKvsObject::function_signalName));
m_pObjectClass->registerFunctionHandler("destructor",KVI_PTR2MEMBER(KviKvsObject::function_destructor));
diff --git a/src/kvirc/kvs/kvi_kvs_processmanager.cpp b/src/kvirc/kvs/kvi_kvs_processmanager.cpp
index 2f3219c..53ac882 100644
--- a/src/kvirc/kvs/kvi_kvs_processmanager.cpp
+++ b/src/kvirc/kvs/kvi_kvs_processmanager.cpp
@@ -330,7 +330,7 @@ void KviKvsProcessAsyncOperation::processExited()
if(m_pData->iFlags & KVI_KVS_PROCESSDESCRIPTOR_TRIGGERTERMINATED)
{
TQString szRetVal;
- szRetVal.setNum(m_pProcess->exiStatus());
+ szRetVal.setNum(m_pProcess->exitStatus());
trigger(EventTerminated,szRetVal);
}
diff --git a/src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp b/src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp
index c303ceb..42338ae 100644
--- a/src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp
+++ b/src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp
@@ -34,7 +34,7 @@ KviKvsTreeNodeCompositeData::KviKvsTreeNodeCompositeData(const TQChar * pLocatio
: KviKvsTreeNodeData(pLocation)
{
#ifdef DEBUGME
- if(pSubData->count() < 2)debug("KviKvsTreeNodeCompositeData constructor called with less than two tqchildren!");
+ if(pSubData->count() < 2)debug("KviKvsTreeNodeCompositeData constructor called with less than two children!");
#endif
m_pSubData = pSubData;
m_pSubData->setAutoDelete(true);
diff --git a/src/kvirc/kvs/kvi_kvs_object.cpp b/src/kvirc/kvs/kvi_kvs_object.cpp
index eaae3fd..e5ff0a5 100644
--- a/src/kvirc/kvs/kvi_kvs_object.cpp
+++ b/src/kvirc/kvs/kvi_kvs_object.cpp
@@ -69,11 +69,11 @@
[big]Basic concepts[/big]
Objects are arranged in tree structures.
- Each object that you create is either toplevel object or a tqchildren
+ Each object that you create is either toplevel object or a children
of another object. A toplevel object is a parentless one.
- Obviously all objects can have tqchildren objects.[br][br]
+ Obviously all objects can have children objects.[br][br]
- When an object is destroyed , all its tqchildren are also destroyed.
+ When an object is destroyed , all its children are also destroyed.
The toplevel objects are automatically destroyed when KVIrc quits.
The objects are global to the entire application (this is different
from previous KVIrc releases where the objects were local
@@ -121,7 +121,7 @@
[example]
[cmd]delete[/cmd] %myobject
[/example]
- If the destroyed object has tqchildren objects , these are destroyed too.[br][br]
+ If the destroyed object has children objects , these are destroyed too.[br][br]
[big]Fields : objects as pseudo-structures[/big]
@@ -196,15 +196,15 @@
[cmd]delete[/cmd] %tmp
[/example]
Another cool function exported by the [class:object]object[/class] class is the
- [classfnc:object]$tqchildren[/classfnc]() function.
- It returns a comma separated list of tqchildren identifiers.[br]
+ [classfnc:object]$children[/classfnc]() function.
+ It returns a comma separated list of children identifiers.[br]
[example]
%tmp = [fnc]$new[/fnc]([class]object[/class],0,myobject)
%tmpchild = [fnc]$new[/fnc]([class]object[/class],%tmp,child1)
%tmpchild = [fnc]$new[/fnc]([class]object[/class],%tmp,child2)
%tmpchild = [fnc]$new[/fnc]([class]object[/class],%tmp,child3)
- [cmd]echo[/cmd] The object's tqchildren list is : %tmp->[classfnc:object]$tqchildren[/classfnc]()
- # Destroy the object and the tqchildren
+ [cmd]echo[/cmd] The object's children list is : %tmp->[classfnc:object]$children[/classfnc]()
+ # Destroy the object and the children
[cmd]delete[/cmd] %tmp
[/example]
There are two special functions for each objects: the "constructor" and the "destructor".
@@ -230,25 +230,25 @@
[cmd]privateimpl[/cmd](%tmp,destructor)
{
%count = 0;
- [cmd]foreach[/cmd](%t,[fnc]$this[/fnc]-&gt;[classfnc:object]$tqchildren[/classfnc]())
+ [cmd]foreach[/cmd](%t,[fnc]$this[/fnc]-&gt;[classfnc:object]$children[/classfnc]())
{
[cmd]echo[/cmd] Children : %t-&gt;[classfnc:object]$name[/classfnc]() with class %t-&gt;[classfnc:object]$class[/classfnc]()
%count++
}
- [cmd]echo[/cmd] Just before destroying my %count tqchildren.
+ [cmd]echo[/cmd] Just before destroying my %count children.
}
# Destroy the object and the tqchildren
[cmd]delete[/cmd] %tmp
[/example]
In the example above four objects have been created.
- A "parent" object named "myobject" , and three tqchildren objects.
+ A "parent" object named "myobject" , and three children objects.
The destructor has been reimplemented for each child object,
to make it "say" its name (Please note the usage of [fnc]$this[/fnc]).
- In the parent destructor the tqchildren have been counted and listed.[br]
+ In the parent destructor the children have been counted and listed.[br]
Then the parent object is destroyed causing to:[br]
- trigger the parent destructor.[br]
- - destroy all the tqchildren (and conseguently trigger all the "individual" destructors).[br][br]
+ - destroy all the children (and conseguently trigger all the "individual" destructors).[br][br]
Not all the object functions must return a value:
If a function does not return a meaningful value , or you just want to ignore it , you can call it in the following way:[br]
@@ -339,7 +339,7 @@
The above class is named "helloworld". It inherits the [class]object[/class] class.
This means that it acquires all the [class]object[/class] fuunctions: [classfnc:object]$name[/classfnc]() ,
- [classfnc:object]$class[/class]() , [classfnc:object]$tqchildren[/classfnc]()...
+ [classfnc:object]$class[/class]() , [classfnc:object]$children[/classfnc]()...
Additionally , it has the $sayhello() function, that "echoes Hello world" to the console.
Now you can create an instance of this class:
[example]
@@ -486,7 +486,7 @@
@description:
This is the base class for all the builtin KVirc object classes.
It exports the functions to retrieve the object name, to iterate
- through tqchildren objects and to lookup a child object by name or class.
+ through children objects and to lookup a child object by name or class.
Additionally , this class provides the builtin timer functionality.
The [classfnc]$constructor[/classfnc] and [classfnc]$destructor[/classfnc]
functions are empty implementations that all the other classes inherit.
@@ -521,15 +521,15 @@
Returns the first child that matches <class> and <name>.
If <class> is an empty string, any class matches,
if <name> is an empty string, any name matches.
- This function traverses the entire tree of tqchildren
+ This function traverses the entire tree of children
but is NOT recursive.
!fn: $childCount()
- Returns the number of tqchildren objects
+ Returns the number of children objects
!fn: $emit(<signal_name>[,parameters])
Emits the signal <signal_name> passing the optional [parameters].
See the [doc:objects]objects documentation[/doc] for an overview of signals and slots.
- !fn: $tqchildren()
- Returns an array of tqchildren object identifiers.
+ !fn: $children()
+ Returns an array of children object identifiers.
!fn: $signalSender()
Returns the current signal sender when in a slot connected to a signal.
In other contexts this function returns an empty string.
@@ -955,7 +955,7 @@ bool KviKvsObject::function_destructor(KviKvsObjectFunctionCall * c)
return true;
}
-bool KviKvsObject::function_tqchildren(KviKvsObjectFunctionCall * c)
+bool KviKvsObject::function_children(KviKvsObjectFunctionCall * c)
{
KviKvsArray * a = new KviKvsArray();
int id=0;
@@ -230,25 +230,25 @@
}
- # Destroy the object and the tqchildren
+ # Destroy the object and the children
[cmd]delete[/cmd] %tmp
[/example]